namespace eldbus { namespace model { 
inline ::efl::eolian::return_traits<int>::type Object::type_get() const
{
   int __return_value =  ::eldbus_model_object_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::type_set( ::efl::eolian::in_traits<int>::type type) const
{
    ::eldbus_model_object_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(type));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Object::address_get() const
{
   const char * __return_value =  ::eldbus_model_object_address_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::address_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type address) const
{
    ::eldbus_model_object_address_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(address));
}
inline ::efl::eolian::return_traits<bool>::type Object::private_get() const
{
   Eina_Bool __return_value =  ::eldbus_model_object_private_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::private_set( ::efl::eolian::in_traits<bool>::type private_) const
{
    ::eldbus_model_object_private_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(private_));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Object::bus_get() const
{
   const char * __return_value =  ::eldbus_model_object_bus_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::bus_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type bus) const
{
    ::eldbus_model_object_bus_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(bus));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Object::path_get() const
{
   const char * __return_value =  ::eldbus_model_object_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::path_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::eldbus_model_object_path_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
inline ::efl::eolian::return_traits<void>::type Object::constructor( ::efl::eolian::in_traits<int>::type type,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type address,  ::efl::eolian::in_traits<bool>::type private_,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type bus,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::eldbus_model_object_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(type)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(address)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(private_)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(bus)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
} } 
namespace eo_cxx {
namespace eldbus { namespace model { 
inline ::efl::eolian::return_traits<int>::type Object::type_get() const
{
   int __return_value =  ::eldbus_model_object_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::type_set( ::efl::eolian::in_traits<int>::type type) const
{
    ::eldbus_model_object_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(type));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Object::address_get() const
{
   const char * __return_value =  ::eldbus_model_object_address_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::address_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type address) const
{
    ::eldbus_model_object_address_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(address));
}
inline ::efl::eolian::return_traits<bool>::type Object::private_get() const
{
   Eina_Bool __return_value =  ::eldbus_model_object_private_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::private_set( ::efl::eolian::in_traits<bool>::type private_) const
{
    ::eldbus_model_object_private_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(private_));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Object::bus_get() const
{
   const char * __return_value =  ::eldbus_model_object_bus_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::bus_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type bus) const
{
    ::eldbus_model_object_bus_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(bus));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Object::path_get() const
{
   const char * __return_value =  ::eldbus_model_object_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Object::path_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::eldbus_model_object_path_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
inline ::efl::eolian::return_traits<void>::type Object::constructor( ::efl::eolian::in_traits<int>::type type,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type address,  ::efl::eolian::in_traits<bool>::type private_,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type bus,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type path) const
{
    ::eldbus_model_object_constructor(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(type)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(address)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(private_)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(bus)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(path));
}
inline eldbus::model::Object::operator ::eldbus::model::Object() const { return *static_cast< ::eldbus::model::Object const*>(static_cast<void const*>(this)); }
inline eldbus::model::Object::operator ::eldbus::model::Object&() { return *static_cast< ::eldbus::model::Object*>(static_cast<void*>(this)); }
inline eldbus::model::Object::operator ::eldbus::model::Object const&() const { return *static_cast< ::eldbus::model::Object const*>(static_cast<void const*>(this)); }
} } }

